package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.CleanRequest;
import com.ruoyi.catdog.service.ICleanRequestService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 清洁要求Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/request")
public class CleanRequestController extends BaseController
{
    @Autowired
    private ICleanRequestService cleanRequestService;

    /**
     * 查询清洁要求列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:list')")
    @GetMapping("/list")
    public TableDataInfo list(CleanRequest cleanRequest)
    {
        startPage();
        List<CleanRequest> list = cleanRequestService.selectCleanRequestList(cleanRequest);
        return getDataTable(list);
    }

    /**
     * 导出清洁要求列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:export')")
    @Log(title = "清洁要求", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CleanRequest cleanRequest) throws IOException {
        List<CleanRequest> list = cleanRequestService.selectCleanRequestList(cleanRequest);
        ExcelUtil<CleanRequest> util = new ExcelUtil<CleanRequest>(CleanRequest.class);
        util.exportExcel(response, list, "清洁要求数据");
    }

    /**
     * 获取清洁要求详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:query')")
    @GetMapping(value = "/{cleanRequestId}")
    public AjaxResult getInfo(@PathVariable("cleanRequestId") Long cleanRequestId)
    {
//        return success(cleanRequestService.selectCleanRequestByCleanRequestId(cleanRequestId));
        return null;
    }

    /**
     * 新增清洁要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:add')")
    @Log(title = "清洁要求", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CleanRequest cleanRequest)
    {
        return toAjax(cleanRequestService.insertCleanRequest(cleanRequest));
    }

    /**
     * 修改清洁要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:edit')")
    @Log(title = "清洁要求", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CleanRequest cleanRequest)
    {
        return toAjax(cleanRequestService.updateCleanRequest(cleanRequest));
    }

    /**
     * 删除清洁要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:request:remove')")
    @Log(title = "清洁要求", businessType = BusinessType.DELETE)
	@DeleteMapping("/{cleanRequestIds}")
    public AjaxResult remove(@PathVariable Long[] cleanRequestIds)
    {
        return toAjax(cleanRequestService.deleteCleanRequestByCleanRequestIds(cleanRequestIds));
    }
}
