package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.DescriptivesConfig;
import com.ruoyi.catdog.service.IDescriptivesConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 数据描述配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/descriptives")
public class DescriptivesConfigController extends BaseController
{
    @Autowired
    private IDescriptivesConfigService descriptivesConfigService;

    /**
     * 查询数据描述配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:list')")
    @GetMapping("/list")
    public TableDataInfo list(DescriptivesConfig descriptivesConfig)
    {
        startPage();
        List<DescriptivesConfig> list = descriptivesConfigService.selectDescriptivesConfigList(descriptivesConfig);
        return getDataTable(list);
    }

    /**
     * 导出数据描述配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:export')")
    @Log(title = "数据描述配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DescriptivesConfig descriptivesConfig) throws IOException {
        List<DescriptivesConfig> list = descriptivesConfigService.selectDescriptivesConfigList(descriptivesConfig);
        ExcelUtil<DescriptivesConfig> util = new ExcelUtil<DescriptivesConfig>(DescriptivesConfig.class);
        util.exportExcel(response, list, "数据描述配置数据");
    }

    /**
     * 获取数据描述配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
//        return success(descriptivesConfigService.selectDescriptivesConfigById(id));
        return null;
    }

    /**
     * 新增数据描述配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:add')")
    @Log(title = "数据描述配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DescriptivesConfig descriptivesConfig)
    {
        return toAjax(descriptivesConfigService.insertDescriptivesConfig(descriptivesConfig));
    }

    /**
     * 修改数据描述配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:edit')")
    @Log(title = "数据描述配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DescriptivesConfig descriptivesConfig)
    {
        return toAjax(descriptivesConfigService.updateDescriptivesConfig(descriptivesConfig));
    }

    /**
     * 删除数据描述配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:descriptives:remove')")
    @Log(title = "数据描述配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(descriptivesConfigService.deleteDescriptivesConfigByIds(ids));
    }
}
