package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.FeedingFood;
import com.ruoyi.catdog.service.IFeedingFoodService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 喂养要求Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/food")
public class FeedingFoodController extends BaseController
{
    @Autowired
    private IFeedingFoodService feedingFoodService;

    /**
     * 查询喂养要求列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:list')")
    @GetMapping("/list")
    public TableDataInfo list(FeedingFood feedingFood)
    {
        startPage();
        List<FeedingFood> list = feedingFoodService.selectFeedingFoodList(feedingFood);
        return getDataTable(list);
    }

    /**
     * 导出喂养要求列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:export')")
    @Log(title = "喂养要求", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FeedingFood feedingFood) throws IOException {
        List<FeedingFood> list = feedingFoodService.selectFeedingFoodList(feedingFood);
        ExcelUtil<FeedingFood> util = new ExcelUtil<FeedingFood>(FeedingFood.class);
        util.exportExcel(response, list, "喂养要求数据");
    }

    /**
     * 获取喂养要求详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:query')")
    @GetMapping(value = "/{feedingFoodId}")
    public AjaxResult getInfo(@PathVariable("feedingFoodId") Long feedingFoodId)
    {
//        return success(feedingFoodService.selectFeedingFoodByFeedingFoodId(feedingFoodId));
        return null;

    }

    /**
     * 新增喂养要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:add')")
    @Log(title = "喂养要求", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FeedingFood feedingFood)
    {
        return toAjax(feedingFoodService.insertFeedingFood(feedingFood));
    }

    /**
     * 修改喂养要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:edit')")
    @Log(title = "喂养要求", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FeedingFood feedingFood)
    {
        return toAjax(feedingFoodService.updateFeedingFood(feedingFood));
    }

    /**
     * 删除喂养要求
     */
    @PreAuthorize("@ss.hasPermi('catdog:food:remove')")
    @Log(title = "喂养要求", businessType = BusinessType.DELETE)
	@DeleteMapping("/{feedingFoodIds}")
    public AjaxResult remove(@PathVariable Long[] feedingFoodIds)
    {
        return toAjax(feedingFoodService.deleteFeedingFoodByFeedingFoodIds(feedingFoodIds));
    }
}
