package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.FeedingFoodType;
import com.ruoyi.catdog.service.IFeedingFoodTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 喂养食品类型Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/type")
public class FeedingFoodTypeController extends BaseController
{
    @Autowired
    private IFeedingFoodTypeService feedingFoodTypeService;

    /**
     * 查询喂养食品类型列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(FeedingFoodType feedingFoodType)
    {
        startPage();
        List<FeedingFoodType> list = feedingFoodTypeService.selectFeedingFoodTypeList(feedingFoodType);
        return getDataTable(list);
    }

    /**
     * 导出喂养食品类型列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:export')")
    @Log(title = "喂养食品类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FeedingFoodType feedingFoodType) throws IOException {
        List<FeedingFoodType> list = feedingFoodTypeService.selectFeedingFoodTypeList(feedingFoodType);
        ExcelUtil<FeedingFoodType> util = new ExcelUtil<FeedingFoodType>(FeedingFoodType.class);
        util.exportExcel(response, list, "喂养食品类型数据");
    }

    /**
     * 获取喂养食品类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:query')")
    @GetMapping(value = "/{feedingFoodTypeId}")
    public AjaxResult getInfo(@PathVariable("feedingFoodTypeId") Long feedingFoodTypeId)
    {
//        return success(feedingFoodTypeService.selectFeedingFoodTypeByFeedingFoodTypeId(feedingFoodTypeId));
        return null;

    }

    /**
     * 新增喂养食品类型
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:add')")
    @Log(title = "喂养食品类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FeedingFoodType feedingFoodType)
    {
        return toAjax(feedingFoodTypeService.insertFeedingFoodType(feedingFoodType));
    }

    /**
     * 修改喂养食品类型
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:edit')")
    @Log(title = "喂养食品类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FeedingFoodType feedingFoodType)
    {
        return toAjax(feedingFoodTypeService.updateFeedingFoodType(feedingFoodType));
    }

    /**
     * 删除喂养食品类型
     */
    @PreAuthorize("@ss.hasPermi('catdog:type:remove')")
    @Log(title = "喂养食品类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{feedingFoodTypeIds}")
    public AjaxResult remove(@PathVariable Long[] feedingFoodTypeIds)
    {
        return toAjax(feedingFoodTypeService.deleteFeedingFoodTypeByFeedingFoodTypeIds(feedingFoodTypeIds));
    }
}
