package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.FeedingRequirements;
import com.ruoyi.catdog.service.IFeedingRequirementsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 喂养要求配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/requirements")
public class FeedingRequirementsController extends BaseController
{
    @Autowired
    private IFeedingRequirementsService feedingRequirementsService;

    /**
     * 查询喂养要求配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:list')")
    @GetMapping("/list")
    public TableDataInfo list(FeedingRequirements feedingRequirements)
    {
        startPage();
        List<FeedingRequirements> list = feedingRequirementsService.selectFeedingRequirementsList(feedingRequirements);
        return getDataTable(list);
    }

    /**
     * 导出喂养要求配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:export')")
    @Log(title = "喂养要求配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FeedingRequirements feedingRequirements) throws IOException {
        List<FeedingRequirements> list = feedingRequirementsService.selectFeedingRequirementsList(feedingRequirements);
        ExcelUtil<FeedingRequirements> util = new ExcelUtil<FeedingRequirements>(FeedingRequirements.class);
        util.exportExcel(response, list, "喂养要求配置数据");
    }

    /**
     * 获取喂养要求配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:query')")
    @GetMapping(value = "/{feedingRequirementsId}")
    public AjaxResult getInfo(@PathVariable("feedingRequirementsId") Long feedingRequirementsId)
    {
//        return success(feedingRequirementsService.selectFeedingRequirementsByFeedingRequirementsId(feedingRequirementsId));
        return null;

    }

    /**
     * 新增喂养要求配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:add')")
    @Log(title = "喂养要求配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FeedingRequirements feedingRequirements)
    {
        return toAjax(feedingRequirementsService.insertFeedingRequirements(feedingRequirements));
    }

    /**
     * 修改喂养要求配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:edit')")
    @Log(title = "喂养要求配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FeedingRequirements feedingRequirements)
    {
        return toAjax(feedingRequirementsService.updateFeedingRequirements(feedingRequirements));
    }

    /**
     * 删除喂养要求配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:requirements:remove')")
    @Log(title = "喂养要求配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{feedingRequirementsIds}")
    public AjaxResult remove(@PathVariable Long[] feedingRequirementsIds)
    {
        return toAjax(feedingRequirementsService.deleteFeedingRequirementsByFeedingRequirementsIds(feedingRequirementsIds));
    }
}
