package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.IndexPageConfig;
import com.ruoyi.catdog.service.IIndexPageConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 首页登录配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Api("首页登录配置")
@RestController
@RequestMapping("/catdog/config")
public class IndexPageConfigController extends BaseController
{
    @Autowired
    private IIndexPageConfigService indexPageConfigService;

    /**
     * 查询首页登录配置列表
     */
    @ApiOperation("登录配置查询")
//    @PreAuthorize("@ss.hasPermi('catdog:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(IndexPageConfig indexPageConfig)
    {
        startPage();
        List<IndexPageConfig> list = indexPageConfigService.selectIndexPageConfigList(indexPageConfig);
        return getDataTable(list);
    }

    /**
     * 导出首页登录配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:config:export')")
    @Log(title = "首页登录配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, IndexPageConfig indexPageConfig) throws IOException {
        List<IndexPageConfig> list = indexPageConfigService.selectIndexPageConfigList(indexPageConfig);
        ExcelUtil<IndexPageConfig> util = new ExcelUtil<IndexPageConfig>(IndexPageConfig.class);
        util.exportExcel(response, list, "首页登录配置数据");
    }

    /**
     * 获取首页登录配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:config:query')")
    @GetMapping(value = "/{indexBackground}")
    public AjaxResult getInfo(@PathVariable("indexBackground") String indexBackground)
    {
        return success(indexPageConfigService.selectIndexPageConfigByIndexBackground(indexBackground));
    }

    /**
     * 新增首页登录配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:config:add')")
    @Log(title = "首页登录配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody IndexPageConfig indexPageConfig)
    {
        return toAjax(indexPageConfigService.insertIndexPageConfig(indexPageConfig));
    }

    /**
     * 修改首页登录配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:config:edit')")
    @Log(title = "首页登录配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody IndexPageConfig indexPageConfig)
    {
        return toAjax(indexPageConfigService.updateIndexPageConfig(indexPageConfig));
    }

    /**
     * 删除首页登录配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:config:remove')")
    @Log(title = "首页登录配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{indexBackgrounds}")
    public AjaxResult remove(@PathVariable String[] indexBackgrounds)
    {
        return toAjax(indexPageConfigService.deleteIndexPageConfigByIndexBackgrounds(indexBackgrounds));
    }
}
