package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.Indexconfig;
import com.ruoyi.catdog.service.IIndexconfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 主页内容配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/indexconfig")
public class IndexconfigController extends BaseController
{
    @Autowired
    private IIndexconfigService indexconfigService;

    /**
     * 查询主页内容配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(Indexconfig indexconfig)
    {
        startPage();
        List<Indexconfig> list = indexconfigService.selectIndexconfigList(indexconfig);
        return getDataTable(list);
    }

    /**
     * 导出主页内容配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:export')")
    @Log(title = "主页内容配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Indexconfig indexconfig) throws IOException {
        List<Indexconfig> list = indexconfigService.selectIndexconfigList(indexconfig);
        ExcelUtil<Indexconfig> util = new ExcelUtil<Indexconfig>(Indexconfig.class);
        util.exportExcel(response, list, "主页内容配置数据");
    }

    /**
     * 获取主页内容配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:query')")
    @GetMapping(value = "/{topCarouselImage}")
    public AjaxResult getInfo(@PathVariable("topCarouselImage") String topCarouselImage)
    {
        return success(indexconfigService.selectIndexconfigByTopCarouselImage(topCarouselImage));
    }

    /**
     * 新增主页内容配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:add')")
    @Log(title = "主页内容配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Indexconfig indexconfig)
    {
        return toAjax(indexconfigService.insertIndexconfig(indexconfig));
    }

    /**
     * 修改主页内容配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:edit')")
    @Log(title = "主页内容配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Indexconfig indexconfig)
    {
        return toAjax(indexconfigService.updateIndexconfig(indexconfig));
    }

    /**
     * 删除主页内容配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:indexconfig:remove')")
    @Log(title = "主页内容配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{topCarouselImages}")
    public AjaxResult remove(@PathVariable String[] topCarouselImages)
    {
        return toAjax(indexconfigService.deleteIndexconfigByTopCarouselImages(topCarouselImages));
    }
}
