package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.Invite;
import com.ruoyi.catdog.service.IInviteService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 邀请海报配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/invite")
public class InviteController extends BaseController
{
    @Autowired
    private IInviteService inviteService;

    /**
     * 查询邀请海报配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:list')")
    @GetMapping("/list")
    public TableDataInfo list(Invite invite)
    {
        startPage();
        List<Invite> list = inviteService.selectInviteList(invite);
        return getDataTable(list);
    }

    /**
     * 导出邀请海报配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:export')")
    @Log(title = "邀请海报配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Invite invite) throws IOException {
        List<Invite> list = inviteService.selectInviteList(invite);
        ExcelUtil<Invite> util = new ExcelUtil<Invite>(Invite.class);
        util.exportExcel(response, list, "邀请海报配置数据");
    }

    /**
     * 获取邀请海报配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(inviteService.selectInviteById(id));
    }

    /**
     * 新增邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:add')")
    @Log(title = "邀请海报配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Invite invite)
    {
        return toAjax(inviteService.insertInvite(invite));
    }

    /**
     * 修改邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:edit')")
    @Log(title = "邀请海报配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Invite invite)
    {
        return toAjax(inviteService.updateInvite(invite));
    }

    /**
     * 删除邀请海报配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:invite:remove')")
    @Log(title = "邀请海报配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(inviteService.deleteInviteByIds(ids));
    }
}
