package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.LicenseImage;
import com.ruoyi.catdog.service.ILicenseImageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 执照图片Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/image")
public class LicenseImageController extends BaseController
{
    @Autowired
    private ILicenseImageService licenseImageService;

    /**
     * 查询执照图片列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:list')")
    @GetMapping("/list")
    public TableDataInfo list(LicenseImage licenseImage)
    {
        startPage();
        List<LicenseImage> list = licenseImageService.selectLicenseImageList(licenseImage);
        return getDataTable(list);
    }

    /**
     * 导出执照图片列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:export')")
    @Log(title = "执照图片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LicenseImage licenseImage) throws IOException {
        List<LicenseImage> list = licenseImageService.selectLicenseImageList(licenseImage);
        ExcelUtil<LicenseImage> util = new ExcelUtil<LicenseImage>(LicenseImage.class);
        util.exportExcel(response, list, "执照图片数据");
    }

    /**
     * 获取执照图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(licenseImageService.selectLicenseImageById(id));
    }

    /**
     * 新增执照图片
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:add')")
    @Log(title = "执照图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LicenseImage licenseImage)
    {
        return toAjax(licenseImageService.insertLicenseImage(licenseImage));
    }

    /**
     * 修改执照图片
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:edit')")
    @Log(title = "执照图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LicenseImage licenseImage)
    {
        return toAjax(licenseImageService.updateLicenseImage(licenseImage));
    }

    /**
     * 删除执照图片
     */
    @PreAuthorize("@ss.hasPermi('catdog:image:remove')")
    @Log(title = "执照图片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(licenseImageService.deleteLicenseImageByIds(ids));
    }
}
