package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.LossOrder;
import com.ruoyi.catdog.service.ILossOrderService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 流失订单Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/order")
public class LossOrderController extends BaseController
{
    @Autowired
    private ILossOrderService lossOrderService;

    /**
     * 查询流失订单列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:list')")
    @GetMapping("/list")
    public TableDataInfo list(LossOrder lossOrder)
    {
        startPage();
        List<LossOrder> list = lossOrderService.selectLossOrderList(lossOrder);
        return getDataTable(list);
    }

    /**
     * 导出流失订单列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:export')")
    @Log(title = "流失订单", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LossOrder lossOrder) throws IOException {
        List<LossOrder> list = lossOrderService.selectLossOrderList(lossOrder);
        ExcelUtil<LossOrder> util = new ExcelUtil<LossOrder>(LossOrder.class);
        util.exportExcel(response, list, "流失订单数据");
    }

    /**
     * 获取流失订单详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:query')")
    @GetMapping(value = "/{lossOrderId}")
    public AjaxResult getInfo(@PathVariable("lossOrderId") Long lossOrderId)
    {
        return success(lossOrderService.selectLossOrderByLossOrderId(lossOrderId));
    }

    /**
     * 新增流失订单
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:add')")
    @Log(title = "流失订单", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LossOrder lossOrder)
    {
        return toAjax(lossOrderService.insertLossOrder(lossOrder));
    }

    /**
     * 修改流失订单
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:edit')")
    @Log(title = "流失订单", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LossOrder lossOrder)
    {
        return toAjax(lossOrderService.updateLossOrder(lossOrder));
    }

    /**
     * 删除流失订单
     */
    @PreAuthorize("@ss.hasPermi('catdog:order:remove')")
    @Log(title = "流失订单", businessType = BusinessType.DELETE)
	@DeleteMapping("/{lossOrderIds}")
    public AjaxResult remove(@PathVariable Long[] lossOrderIds)
    {
        return toAjax(lossOrderService.deleteLossOrderByLossOrderIds(lossOrderIds));
    }
}
