package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.ManualConfig;
import com.ruoyi.catdog.service.IManualConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 伴宠师手册配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/manualconfig")
public class ManualConfigController extends BaseController
{
    @Autowired
    private IManualConfigService manualConfigService;

    /**
     * 查询伴宠师手册配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(ManualConfig manualConfig)
    {
        startPage();
        List<ManualConfig> list = manualConfigService.selectManualConfigList(manualConfig);
        return getDataTable(list);
    }

    /**
     * 导出伴宠师手册配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:export')")
    @Log(title = "伴宠师手册配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ManualConfig manualConfig) throws IOException {
        List<ManualConfig> list = manualConfigService.selectManualConfigList(manualConfig);
        ExcelUtil<ManualConfig> util = new ExcelUtil<ManualConfig>(ManualConfig.class);
        util.exportExcel(response, list, "伴宠师手册配置数据");
    }

    /**
     * 获取伴宠师手册配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(manualConfigService.selectManualConfigById(id));
    }

    /**
     * 新增伴宠师手册配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:add')")
    @Log(title = "伴宠师手册配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ManualConfig manualConfig)
    {
        return toAjax(manualConfigService.insertManualConfig(manualConfig));
    }

    /**
     * 修改伴宠师手册配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:edit')")
    @Log(title = "伴宠师手册配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ManualConfig manualConfig)
    {
        return toAjax(manualConfigService.updateManualConfig(manualConfig));
    }

    /**
     * 删除伴宠师手册配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:manualconfig:remove')")
    @Log(title = "伴宠师手册配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(manualConfigService.deleteManualConfigByIds(ids));
    }
}
