package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.OrdersRecords;
import com.ruoyi.catdog.service.IOrdersRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 接单记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/records")
public class OrdersRecordsController extends BaseController
{
    @Autowired
    private IOrdersRecordsService ordersRecordsService;

    /**
     * 查询接单记录列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:list')")
    @GetMapping("/list")
    public TableDataInfo list(OrdersRecords ordersRecords)
    {
        startPage();
        List<OrdersRecords> list = ordersRecordsService.selectOrdersRecordsList(ordersRecords);
        return getDataTable(list);
    }

    /**
     * 导出接单记录列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:export')")
    @Log(title = "接单记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, OrdersRecords ordersRecords) throws IOException {
        List<OrdersRecords> list = ordersRecordsService.selectOrdersRecordsList(ordersRecords);
        ExcelUtil<OrdersRecords> util = new ExcelUtil<OrdersRecords>(OrdersRecords.class);
        util.exportExcel(response, list, "接单记录数据");
    }

    /**
     * 获取接单记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:query')")
    @GetMapping(value = "/{ordersRecordsId}")
    public AjaxResult getInfo(@PathVariable("ordersRecordsId") Long ordersRecordsId)
    {
        return success(ordersRecordsService.selectOrdersRecordsByOrdersRecordsId(ordersRecordsId));
    }

    /**
     * 新增接单记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:add')")
    @Log(title = "接单记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody OrdersRecords ordersRecords)
    {
        return toAjax(ordersRecordsService.insertOrdersRecords(ordersRecords));
    }

    /**
     * 修改接单记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:edit')")
    @Log(title = "接单记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody OrdersRecords ordersRecords)
    {
        return toAjax(ordersRecordsService.updateOrdersRecords(ordersRecords));
    }

    /**
     * 删除接单记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:records:remove')")
    @Log(title = "接单记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ordersRecordsIds}")
    public AjaxResult remove(@PathVariable Long[] ordersRecordsIds)
    {
        return toAjax(ordersRecordsService.deleteOrdersRecordsByOrdersRecordsIds(ordersRecordsIds));
    }
}
