package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PaperPromptConfig;
import com.ruoyi.catdog.service.IPaperPromptConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 证件提示配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/paperpromptconfig")
public class PaperPromptConfigController extends BaseController
{
    @Autowired
    private IPaperPromptConfigService paperPromptConfigService;

    /**
     * 查询证件提示配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(PaperPromptConfig paperPromptConfig)
    {
        startPage();
        List<PaperPromptConfig> list = paperPromptConfigService.selectPaperPromptConfigList(paperPromptConfig);
        return getDataTable(list);
    }

    /**
     * 导出证件提示配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:export')")
    @Log(title = "证件提示配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PaperPromptConfig paperPromptConfig) throws IOException {
        List<PaperPromptConfig> list = paperPromptConfigService.selectPaperPromptConfigList(paperPromptConfig);
        ExcelUtil<PaperPromptConfig> util = new ExcelUtil<PaperPromptConfig>(PaperPromptConfig.class);
        util.exportExcel(response, list, "证件提示配置数据");
    }

    /**
     * 获取证件提示配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(paperPromptConfigService.selectPaperPromptConfigById(id));
    }

    /**
     * 新增证件提示配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:add')")
    @Log(title = "证件提示配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PaperPromptConfig paperPromptConfig)
    {
        return toAjax(paperPromptConfigService.insertPaperPromptConfig(paperPromptConfig));
    }

    /**
     * 修改证件提示配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:edit')")
    @Log(title = "证件提示配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PaperPromptConfig paperPromptConfig)
    {
        return toAjax(paperPromptConfigService.updatePaperPromptConfig(paperPromptConfig));
    }

    /**
     * 删除证件提示配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:paperpromptconfig:remove')")
    @Log(title = "证件提示配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(paperPromptConfigService.deletePaperPromptConfigByIds(ids));
    }
}
