package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.Partnerbinding;
import com.ruoyi.catdog.service.IPartnerbindingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人绑定Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/partnerbinding")
public class PartnerbindingController extends BaseController
{
    @Autowired
    private IPartnerbindingService partnerbindingService;

    /**
     * 查询合伙人绑定列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:list')")
    @GetMapping("/list")
    public TableDataInfo list(Partnerbinding partnerbinding)
    {
        startPage();
        List<Partnerbinding> list = partnerbindingService.selectPartnerbindingList(partnerbinding);
        return getDataTable(list);
    }

    /**
     * 导出合伙人绑定列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:export')")
    @Log(title = "合伙人绑定", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Partnerbinding partnerbinding) throws IOException {
        List<Partnerbinding> list = partnerbindingService.selectPartnerbindingList(partnerbinding);
        ExcelUtil<Partnerbinding> util = new ExcelUtil<Partnerbinding>(Partnerbinding.class);
        util.exportExcel(response, list, "合伙人绑定数据");
    }

    /**
     * 获取合伙人绑定详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(partnerbindingService.selectPartnerbindingById(id));
    }

    /**
     * 新增合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:add')")
    @Log(title = "合伙人绑定", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Partnerbinding partnerbinding)
    {
        return toAjax(partnerbindingService.insertPartnerbinding(partnerbinding));
    }

    /**
     * 修改合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:edit')")
    @Log(title = "合伙人绑定", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Partnerbinding partnerbinding)
    {
        return toAjax(partnerbindingService.updatePartnerbinding(partnerbinding));
    }

    /**
     * 删除合伙人绑定
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerbinding:remove')")
    @Log(title = "合伙人绑定", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(partnerbindingService.deletePartnerbindingByIds(ids));
    }
}
