package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.Partnerdata;
import com.ruoyi.catdog.service.IPartnerdataService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人数据Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/partnerdata")
public class PartnerdataController extends BaseController
{
    @Autowired
    private IPartnerdataService partnerdataService;

    /**
     * 查询合伙人数据列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:list')")
    @GetMapping("/list")
    public TableDataInfo list(Partnerdata partnerdata)
    {
        startPage();
        List<Partnerdata> list = partnerdataService.selectPartnerdataList(partnerdata);
        return getDataTable(list);
    }

    /**
     * 导出合伙人数据列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:export')")
    @Log(title = "合伙人数据", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Partnerdata partnerdata) throws IOException {
        List<Partnerdata> list = partnerdataService.selectPartnerdataList(partnerdata);
        ExcelUtil<Partnerdata> util = new ExcelUtil<Partnerdata>(Partnerdata.class);
        util.exportExcel(response, list, "合伙人数据数据");
    }

    /**
     * 获取合伙人数据详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(partnerdataService.selectPartnerdataById(id));
    }

    /**
     * 新增合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:add')")
    @Log(title = "合伙人数据", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Partnerdata partnerdata)
    {
        return toAjax(partnerdataService.insertPartnerdata(partnerdata));
    }

    /**
     * 修改合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:edit')")
    @Log(title = "合伙人数据", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Partnerdata partnerdata)
    {
        return toAjax(partnerdataService.updatePartnerdata(partnerdata));
    }

    /**
     * 删除合伙人数据
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerdata:remove')")
    @Log(title = "合伙人数据", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(partnerdataService.deletePartnerdataByIds(ids));
    }
}
