package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.Partnerincome;
import com.ruoyi.catdog.service.IPartnerincomeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 合伙人等级记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/partnerincome")
public class PartnerincomeController extends BaseController
{
    @Autowired
    private IPartnerincomeService partnerincomeService;

    /**
     * 查询合伙人等级记录列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:list')")
    @GetMapping("/list")
    public TableDataInfo list(Partnerincome partnerincome)
    {
        startPage();
        List<Partnerincome> list = partnerincomeService.selectPartnerincomeList(partnerincome);
        return getDataTable(list);
    }

    /**
     * 导出合伙人等级记录列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:export')")
    @Log(title = "合伙人等级记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Partnerincome partnerincome) throws IOException {
        List<Partnerincome> list = partnerincomeService.selectPartnerincomeList(partnerincome);
        ExcelUtil<Partnerincome> util = new ExcelUtil<Partnerincome>(Partnerincome.class);
        util.exportExcel(response, list, "合伙人等级记录数据");
    }

    /**
     * 获取合伙人等级记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(partnerincomeService.selectPartnerincomeById(id));
    }

    /**
     * 新增合伙人等级记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:add')")
    @Log(title = "合伙人等级记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Partnerincome partnerincome)
    {
        return toAjax(partnerincomeService.insertPartnerincome(partnerincome));
    }

    /**
     * 修改合伙人等级记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:edit')")
    @Log(title = "合伙人等级记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Partnerincome partnerincome)
    {
        return toAjax(partnerincomeService.updatePartnerincome(partnerincome));
    }

    /**
     * 删除合伙人等级记录
     */
    @PreAuthorize("@ss.hasPermi('catdog:partnerincome:remove')")
    @Log(title = "合伙人等级记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(partnerincomeService.deletePartnerincomeByIds(ids));
    }
}
