package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PetPersonalityConfig;
import com.ruoyi.catdog.service.IPetPersonalityConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 宠物性格快捷选择配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/petpersonalityconfig")
public class PetPersonalityConfigController extends BaseController
{
    @Autowired
    private IPetPersonalityConfigService petPersonalityConfigService;

    /**
     * 查询宠物性格快捷选择配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetPersonalityConfig petPersonalityConfig)
    {
        startPage();
        List<PetPersonalityConfig> list = petPersonalityConfigService.selectPetPersonalityConfigList(petPersonalityConfig);
        return getDataTable(list);
    }

    /**
     * 导出宠物性格快捷选择配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:export')")
    @Log(title = "宠物性格快捷选择配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetPersonalityConfig petPersonalityConfig) throws IOException {
        List<PetPersonalityConfig> list = petPersonalityConfigService.selectPetPersonalityConfigList(petPersonalityConfig);
        ExcelUtil<PetPersonalityConfig> util = new ExcelUtil<PetPersonalityConfig>(PetPersonalityConfig.class);
        util.exportExcel(response, list, "宠物性格快捷选择配置数据");
    }

    /**
     * 获取宠物性格快捷选择配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(petPersonalityConfigService.selectPetPersonalityConfigById(id));
    }

    /**
     * 新增宠物性格快捷选择配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:add')")
    @Log(title = "宠物性格快捷选择配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetPersonalityConfig petPersonalityConfig)
    {
        return toAjax(petPersonalityConfigService.insertPetPersonalityConfig(petPersonalityConfig));
    }

    /**
     * 修改宠物性格快捷选择配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:edit')")
    @Log(title = "宠物性格快捷选择配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetPersonalityConfig petPersonalityConfig)
    {
        return toAjax(petPersonalityConfigService.updatePetPersonalityConfig(petPersonalityConfig));
    }

    /**
     * 删除宠物性格快捷选择配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petpersonalityconfig:remove')")
    @Log(title = "宠物性格快捷选择配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(petPersonalityConfigService.deletePetPersonalityConfigByIds(ids));
    }
}
