package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PetProfileConfig;
import com.ruoyi.catdog.service.IPetProfileConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 宠物档案配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/petprofileconfig")
public class PetProfileConfigController extends BaseController
{
    @Autowired
    private IPetProfileConfigService petProfileConfigService;

    /**
     * 查询宠物档案配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetProfileConfig petProfileConfig)
    {
        startPage();
        List<PetProfileConfig> list = petProfileConfigService.selectPetProfileConfigList(petProfileConfig);
        return getDataTable(list);
    }

    /**
     * 导出宠物档案配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:export')")
    @Log(title = "宠物档案配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetProfileConfig petProfileConfig) throws IOException {
        List<PetProfileConfig> list = petProfileConfigService.selectPetProfileConfigList(petProfileConfig);
        ExcelUtil<PetProfileConfig> util = new ExcelUtil<PetProfileConfig>(PetProfileConfig.class);
        util.exportExcel(response, list, "宠物档案配置数据");
    }

    /**
     * 获取宠物档案配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(petProfileConfigService.selectPetProfileConfigById(id));
    }

    /**
     * 新增宠物档案配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:add')")
    @Log(title = "宠物档案配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetProfileConfig petProfileConfig)
    {
        return toAjax(petProfileConfigService.insertPetProfileConfig(petProfileConfig));
    }

    /**
     * 修改宠物档案配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:edit')")
    @Log(title = "宠物档案配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetProfileConfig petProfileConfig)
    {
        return toAjax(petProfileConfigService.updatePetProfileConfig(petProfileConfig));
    }

    /**
     * 删除宠物档案配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:petprofileconfig:remove')")
    @Log(title = "宠物档案配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(petProfileConfigService.deletePetProfileConfigByIds(ids));
    }
}
