package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PetTeacharCheck;
import com.ruoyi.catdog.service.IPetTeacharCheckService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 打卡Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/check")
public class PetTeacharCheckController extends BaseController
{
    @Autowired
    private IPetTeacharCheckService petTeacharCheckService;

    /**
     * 查询打卡列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetTeacharCheck petTeacharCheck)
    {
        startPage();
        List<PetTeacharCheck> list = petTeacharCheckService.selectPetTeacharCheckList(petTeacharCheck);
        return getDataTable(list);
    }

    /**
     * 导出打卡列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:export')")
    @Log(title = "打卡", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetTeacharCheck petTeacharCheck) throws IOException {
        List<PetTeacharCheck> list = petTeacharCheckService.selectPetTeacharCheckList(petTeacharCheck);
        ExcelUtil<PetTeacharCheck> util = new ExcelUtil<PetTeacharCheck>(PetTeacharCheck.class);
        util.exportExcel(response, list, "打卡数据");
    }

    /**
     * 获取打卡详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:query')")
    @GetMapping(value = "/{checkId}")
    public AjaxResult getInfo(@PathVariable("checkId") Long checkId)
    {
        return success(petTeacharCheckService.selectPetTeacharCheckByCheckId(checkId));
    }

    /**
     * 新增打卡
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:add')")
    @Log(title = "打卡", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetTeacharCheck petTeacharCheck)
    {
        return toAjax(petTeacharCheckService.insertPetTeacharCheck(petTeacharCheck));
    }

    /**
     * 修改打卡
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:edit')")
    @Log(title = "打卡", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetTeacharCheck petTeacharCheck)
    {
        return toAjax(petTeacharCheckService.updatePetTeacharCheck(petTeacharCheck));
    }

    /**
     * 删除打卡
     */
    @PreAuthorize("@ss.hasPermi('catdog:check:remove')")
    @Log(title = "打卡", businessType = BusinessType.DELETE)
	@DeleteMapping("/{checkIds}")
    public AjaxResult remove(@PathVariable Long[] checkIds)
    {
        return toAjax(petTeacharCheckService.deletePetTeacharCheckByCheckIds(checkIds));
    }
}
