package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PetTeacherGrade;
import com.ruoyi.catdog.service.IPetTeacherGradeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 伴宠师等级配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/grade")
public class PetTeacherGradeController extends BaseController
{
    @Autowired
    private IPetTeacherGradeService petTeacherGradeService;

    /**
     * 查询伴宠师等级配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetTeacherGrade petTeacherGrade)
    {
        startPage();
        List<PetTeacherGrade> list = petTeacherGradeService.selectPetTeacherGradeList(petTeacherGrade);
        return getDataTable(list);
    }

    /**
     * 导出伴宠师等级配置列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:export')")
    @Log(title = "伴宠师等级配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetTeacherGrade petTeacherGrade) throws IOException {
        List<PetTeacherGrade> list = petTeacherGradeService.selectPetTeacherGradeList(petTeacherGrade);
        ExcelUtil<PetTeacherGrade> util = new ExcelUtil<PetTeacherGrade>(PetTeacherGrade.class);
        util.exportExcel(response, list, "伴宠师等级配置数据");
    }

    /**
     * 获取伴宠师等级配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:query')")
    @GetMapping(value = "/{gradeId}")
    public AjaxResult getInfo(@PathVariable("gradeId") String gradeId)
    {
        return success(petTeacherGradeService.selectPetTeacherGradeByGradeId(gradeId));
    }

    /**
     * 新增伴宠师等级配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:add')")
    @Log(title = "伴宠师等级配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetTeacherGrade petTeacherGrade)
    {
        return toAjax(petTeacherGradeService.insertPetTeacherGrade(petTeacherGrade));
    }

    /**
     * 修改伴宠师等级配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:edit')")
    @Log(title = "伴宠师等级配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetTeacherGrade petTeacherGrade)
    {
        return toAjax(petTeacherGradeService.updatePetTeacherGrade(petTeacherGrade));
    }

    /**
     * 删除伴宠师等级配置
     */
    @PreAuthorize("@ss.hasPermi('catdog:grade:remove')")
    @Log(title = "伴宠师等级配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{gradeIds}")
    public AjaxResult remove(@PathVariable String[] gradeIds)
    {
        return toAjax(petTeacherGradeService.deletePetTeacherGradeByGradeIds(gradeIds));
    }
}
