package com.ruoyi.catdog.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.catdog.domain.PetTeacherInfo;
import com.ruoyi.catdog.service.IPetTeacherInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 伴宠师信息Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/catdog/info")
public class PetTeacherInfoController extends BaseController
{
    @Autowired
    private IPetTeacherInfoService petTeacherInfoService;

    /**
     * 查询伴宠师信息列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetTeacherInfo petTeacherInfo)
    {
        startPage();
        List<PetTeacherInfo> list = petTeacherInfoService.selectPetTeacherInfoList(petTeacherInfo);
        return getDataTable(list);
    }

    /**
     * 导出伴宠师信息列表
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:export')")
    @Log(title = "伴宠师信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetTeacherInfo petTeacherInfo) throws IOException {
        List<PetTeacherInfo> list = petTeacherInfoService.selectPetTeacherInfoList(petTeacherInfo);
        ExcelUtil<PetTeacherInfo> util = new ExcelUtil<PetTeacherInfo>(PetTeacherInfo.class);
        util.exportExcel(response, list, "伴宠师信息数据");
    }

    /**
     * 获取伴宠师信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:query')")
    @GetMapping(value = "/{petTeacherId}")
    public AjaxResult getInfo(@PathVariable("petTeacherId") Long petTeacherId)
    {
        return success(petTeacherInfoService.selectPetTeacherInfoByPetTeacherId(petTeacherId));
    }

    /**
     * 新增伴宠师信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:add')")
    @Log(title = "伴宠师信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetTeacherInfo petTeacherInfo)
    {
        return toAjax(petTeacherInfoService.insertPetTeacherInfo(petTeacherInfo));
    }

    /**
     * 修改伴宠师信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:edit')")
    @Log(title = "伴宠师信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetTeacherInfo petTeacherInfo)
    {
        return toAjax(petTeacherInfoService.updatePetTeacherInfo(petTeacherInfo));
    }

    /**
     * 删除伴宠师信息
     */
    @PreAuthorize("@ss.hasPermi('catdog:info:remove')")
    @Log(title = "伴宠师信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{petTeacherIds}")
    public AjaxResult remove(@PathVariable Long[] petTeacherIds)
    {
        return toAjax(petTeacherInfoService.deletePetTeacherInfoByPetTeacherIds(petTeacherIds));
    }
}
