package com.ruoyi.catdog.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.catdog.mapper.CleanItemsMapper;
import com.ruoyi.catdog.domain.CleanItems;
import com.ruoyi.catdog.service.ICleanItemsService;

/**
 * 清洁物品Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class CleanItemsServiceImpl implements ICleanItemsService 
{
    @Autowired
    private CleanItemsMapper cleanItemsMapper;

    /**
     * 查询清洁物品
     * 
     * @param cleanItemsId 清洁物品主键
     * @return 清洁物品
     */
    @Override
    public CleanItems selectCleanItemsByCleanItemsId(Long cleanItemsId)
    {
        return cleanItemsMapper.selectCleanItemsByCleanItemsId(cleanItemsId);
    }

    /**
     * 查询清洁物品列表
     * 
     * @param cleanItems 清洁物品
     * @return 清洁物品
     */
    @Override
    public List<CleanItems> selectCleanItemsList(CleanItems cleanItems)
    {
        return cleanItemsMapper.selectCleanItemsList(cleanItems);
    }

    /**
     * 新增清洁物品
     * 
     * @param cleanItems 清洁物品
     * @return 结果
     */
    @Override
    public int insertCleanItems(CleanItems cleanItems)
    {
        cleanItems.setCreateTime(DateUtils.getNowDate());
        return cleanItemsMapper.insertCleanItems(cleanItems);
    }

    /**
     * 修改清洁物品
     * 
     * @param cleanItems 清洁物品
     * @return 结果
     */
    @Override
    public int updateCleanItems(CleanItems cleanItems)
    {
        cleanItems.setUpdateTime(DateUtils.getNowDate());
        return cleanItemsMapper.updateCleanItems(cleanItems);
    }

    /**
     * 批量删除清洁物品
     * 
     * @param cleanItemsIds 需要删除的清洁物品主键
     * @return 结果
     */
    @Override
    public int deleteCleanItemsByCleanItemsIds(Long[] cleanItemsIds)
    {
        return cleanItemsMapper.deleteCleanItemsByCleanItemsIds(cleanItemsIds);
    }

    /**
     * 删除清洁物品信息
     * 
     * @param cleanItemsId 清洁物品主键
     * @return 结果
     */
    @Override
    public int deleteCleanItemsByCleanItemsId(Long cleanItemsId)
    {
        return cleanItemsMapper.deleteCleanItemsByCleanItemsId(cleanItemsId);
    }
}
