package com.ruoyi.catdog.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.catdog.mapper.FeedingFoodTypeMapper;
import com.ruoyi.catdog.domain.FeedingFoodType;
import com.ruoyi.catdog.service.IFeedingFoodTypeService;

/**
 * 喂养食品类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class FeedingFoodTypeServiceImpl implements IFeedingFoodTypeService 
{
    @Autowired
    private FeedingFoodTypeMapper feedingFoodTypeMapper;

    /**
     * 查询喂养食品类型
     * 
     * @param feedingFoodTypeId 喂养食品类型主键
     * @return 喂养食品类型
     */
    @Override
    public FeedingFoodType selectFeedingFoodTypeByFeedingFoodTypeId(Long feedingFoodTypeId)
    {
        return feedingFoodTypeMapper.selectFeedingFoodTypeByFeedingFoodTypeId(feedingFoodTypeId);
    }

    /**
     * 查询喂养食品类型列表
     * 
     * @param feedingFoodType 喂养食品类型
     * @return 喂养食品类型
     */
    @Override
    public List<FeedingFoodType> selectFeedingFoodTypeList(FeedingFoodType feedingFoodType)
    {
        return feedingFoodTypeMapper.selectFeedingFoodTypeList(feedingFoodType);
    }

    /**
     * 新增喂养食品类型
     * 
     * @param feedingFoodType 喂养食品类型
     * @return 结果
     */
    @Override
    public int insertFeedingFoodType(FeedingFoodType feedingFoodType)
    {
        feedingFoodType.setCreateTime(DateUtils.getNowDate());
        return feedingFoodTypeMapper.insertFeedingFoodType(feedingFoodType);
    }

    /**
     * 修改喂养食品类型
     * 
     * @param feedingFoodType 喂养食品类型
     * @return 结果
     */
    @Override
    public int updateFeedingFoodType(FeedingFoodType feedingFoodType)
    {
        feedingFoodType.setUpdateTime(DateUtils.getNowDate());
        return feedingFoodTypeMapper.updateFeedingFoodType(feedingFoodType);
    }

    /**
     * 批量删除喂养食品类型
     * 
     * @param feedingFoodTypeIds 需要删除的喂养食品类型主键
     * @return 结果
     */
    @Override
    public int deleteFeedingFoodTypeByFeedingFoodTypeIds(Long[] feedingFoodTypeIds)
    {
        return feedingFoodTypeMapper.deleteFeedingFoodTypeByFeedingFoodTypeIds(feedingFoodTypeIds);
    }

    /**
     * 删除喂养食品类型信息
     * 
     * @param feedingFoodTypeId 喂养食品类型主键
     * @return 结果
     */
    @Override
    public int deleteFeedingFoodTypeByFeedingFoodTypeId(Long feedingFoodTypeId)
    {
        return feedingFoodTypeMapper.deleteFeedingFoodTypeByFeedingFoodTypeId(feedingFoodTypeId);
    }
}
