package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AddValueService;
import com.ruoyi.system.service.IAddValueServiceService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 增值服务Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/service")
public class AddValueServiceController extends BaseController
{
    @Autowired
    private IAddValueServiceService addValueServiceService;

    /**
     * 查询增值服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:service:list')")
    @GetMapping("/list")
    public TableDataInfo list(AddValueService addValueService)
    {
        startPage();
        List<AddValueService> list = addValueServiceService.selectAddValueServiceList(addValueService);
        return getDataTable(list);
    }

    /**
     * 导出增值服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:service:export')")
    @Log(title = "增值服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AddValueService addValueService) throws IOException {
        List<AddValueService> list = addValueServiceService.selectAddValueServiceList(addValueService);
        ExcelUtil<AddValueService> util = new ExcelUtil<AddValueService>(AddValueService.class);
        util.exportExcel(response, list, "增值服务数据");
    }

    /**
     * 获取增值服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:service:query')")
    @GetMapping(value = "/{addValueServiceId}")
    public AjaxResult getInfo(@PathVariable("addValueServiceId") Long addValueServiceId)
    {
        return success(addValueServiceService.selectAddValueServiceByAddValueServiceId(addValueServiceId));
    }

    /**
     * 新增增值服务
     */
    @PreAuthorize("@ss.hasPermi('system:service:add')")
    @Log(title = "增值服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AddValueService addValueService)
    {
        return toAjax(addValueServiceService.insertAddValueService(addValueService));
    }

    /**
     * 修改增值服务
     */
    @PreAuthorize("@ss.hasPermi('system:service:edit')")
    @Log(title = "增值服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AddValueService addValueService)
    {
        return toAjax(addValueServiceService.updateAddValueService(addValueService));
    }

    /**
     * 删除增值服务
     */
    @PreAuthorize("@ss.hasPermi('system:service:remove')")
    @Log(title = "增值服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{addValueServiceIds}")
    public AjaxResult remove(@PathVariable Long[] addValueServiceIds)
    {
        return toAjax(addValueServiceService.deleteAddValueServiceByAddValueServiceIds(addValueServiceIds));
    }
}
