package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AddValueServiceRecords;
import com.ruoyi.system.service.IAddValueServiceRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 增值服务记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/records")
public class AddValueServiceRecordsController extends BaseController
{
    @Autowired
    private IAddValueServiceRecordsService addValueServiceRecordsService;

    /**
     * 查询增值服务记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:records:list')")
    @GetMapping("/list")
    public TableDataInfo list(AddValueServiceRecords addValueServiceRecords)
    {
        startPage();
        List<AddValueServiceRecords> list = addValueServiceRecordsService.selectAddValueServiceRecordsList(addValueServiceRecords);
        return getDataTable(list);
    }

    /**
     * 导出增值服务记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:records:export')")
    @Log(title = "增值服务记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AddValueServiceRecords addValueServiceRecords) throws IOException {
        List<AddValueServiceRecords> list = addValueServiceRecordsService.selectAddValueServiceRecordsList(addValueServiceRecords);
        ExcelUtil<AddValueServiceRecords> util = new ExcelUtil<AddValueServiceRecords>(AddValueServiceRecords.class);
        util.exportExcel(response, list, "增值服务记录数据");
    }

    /**
     * 获取增值服务记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:records:query')")
    @GetMapping(value = "/{addValueServiceRecordsId}")
    public AjaxResult getInfo(@PathVariable("addValueServiceRecordsId") Long addValueServiceRecordsId)
    {
        return success(addValueServiceRecordsService.selectAddValueServiceRecordsByAddValueServiceRecordsId(addValueServiceRecordsId));
    }

    /**
     * 新增增值服务记录
     */
    @PreAuthorize("@ss.hasPermi('system:records:add')")
    @Log(title = "增值服务记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AddValueServiceRecords addValueServiceRecords)
    {
        return toAjax(addValueServiceRecordsService.insertAddValueServiceRecords(addValueServiceRecords));
    }

    /**
     * 修改增值服务记录
     */
    @PreAuthorize("@ss.hasPermi('system:records:edit')")
    @Log(title = "增值服务记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AddValueServiceRecords addValueServiceRecords)
    {
        return toAjax(addValueServiceRecordsService.updateAddValueServiceRecords(addValueServiceRecords));
    }

    /**
     * 删除增值服务记录
     */
    @PreAuthorize("@ss.hasPermi('system:records:remove')")
    @Log(title = "增值服务记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{addValueServiceRecordsIds}")
    public AjaxResult remove(@PathVariable Long[] addValueServiceRecordsIds)
    {
        return toAjax(addValueServiceRecordsService.deleteAddValueServiceRecordsByAddValueServiceRecordsIds(addValueServiceRecordsIds));
    }
}
