package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AdditionalServices;
import com.ruoyi.system.service.IAdditionalServicesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 附加服务Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/services")
public class AdditionalServicesController extends BaseController
{
    @Autowired
    private IAdditionalServicesService additionalServicesService;

    /**
     * 查询附加服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdditionalServices additionalServices)
    {
        startPage();
        List<AdditionalServices> list = additionalServicesService.selectAdditionalServicesList(additionalServices);
        return getDataTable(list);
    }

    /**
     * 导出附加服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:services:export')")
    @Log(title = "附加服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdditionalServices additionalServices) throws IOException {
        List<AdditionalServices> list = additionalServicesService.selectAdditionalServicesList(additionalServices);
        ExcelUtil<AdditionalServices> util = new ExcelUtil<AdditionalServices>(AdditionalServices.class);
        util.exportExcel(response, list, "附加服务数据");
    }

    /**
     * 获取附加服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:services:query')")
    @GetMapping(value = "/{additionalServicesId}")
    public AjaxResult getInfo(@PathVariable("additionalServicesId") Long additionalServicesId)
    {
        return success(additionalServicesService.selectAdditionalServicesByAdditionalServicesId(additionalServicesId));
    }

    /**
     * 新增附加服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:add')")
    @Log(title = "附加服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdditionalServices additionalServices)
    {
        return toAjax(additionalServicesService.insertAdditionalServices(additionalServices));
    }

    /**
     * 修改附加服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:edit')")
    @Log(title = "附加服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdditionalServices additionalServices)
    {
        return toAjax(additionalServicesService.updateAdditionalServices(additionalServices));
    }

    /**
     * 删除附加服务
     */
    @PreAuthorize("@ss.hasPermi('system:services:remove')")
    @Log(title = "附加服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{additionalServicesIds}")
    public AjaxResult remove(@PathVariable Long[] additionalServicesIds)
    {
        return toAjax(additionalServicesService.deleteAdditionalServicesByAdditionalServicesIds(additionalServicesIds));
    }
}
