package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AdditionalServicesType;
import com.ruoyi.system.service.IAdditionalServicesTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 附加服务类型Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/type")
public class AdditionalServicesTypeController extends BaseController
{
    @Autowired
    private IAdditionalServicesTypeService additionalServicesTypeService;

    /**
     * 查询附加服务类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(AdditionalServicesType additionalServicesType)
    {
        startPage();
        List<AdditionalServicesType> list = additionalServicesTypeService.selectAdditionalServicesTypeList(additionalServicesType);
        return getDataTable(list);
    }

    /**
     * 导出附加服务类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:type:export')")
    @Log(title = "附加服务类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AdditionalServicesType additionalServicesType) throws IOException {
        List<AdditionalServicesType> list = additionalServicesTypeService.selectAdditionalServicesTypeList(additionalServicesType);
        ExcelUtil<AdditionalServicesType> util = new ExcelUtil<AdditionalServicesType>(AdditionalServicesType.class);
        util.exportExcel(response, list, "附加服务类型数据");
    }

    /**
     * 获取附加服务类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:type:query')")
    @GetMapping(value = "/{additionalServicesTypeId}")
    public AjaxResult getInfo(@PathVariable("additionalServicesTypeId") Long additionalServicesTypeId)
    {
        return success(additionalServicesTypeService.selectAdditionalServicesTypeByAdditionalServicesTypeId(additionalServicesTypeId));
    }

    /**
     * 新增附加服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:type:add')")
    @Log(title = "附加服务类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AdditionalServicesType additionalServicesType)
    {
        return toAjax(additionalServicesTypeService.insertAdditionalServicesType(additionalServicesType));
    }

    /**
     * 修改附加服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:type:edit')")
    @Log(title = "附加服务类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AdditionalServicesType additionalServicesType)
    {
        return toAjax(additionalServicesTypeService.updateAdditionalServicesType(additionalServicesType));
    }

    /**
     * 删除附加服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:type:remove')")
    @Log(title = "附加服务类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{additionalServicesTypeIds}")
    public AjaxResult remove(@PathVariable Long[] additionalServicesTypeIds)
    {
        return toAjax(additionalServicesTypeService.deleteAdditionalServicesTypeByAdditionalServicesTypeIds(additionalServicesTypeIds));
    }
}
