package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AddressConfig;
import com.ruoyi.system.service.IAddressConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 接单地址配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/AddressConfig")
public class AddressConfigController extends BaseController
{
    @Autowired
    private IAddressConfigService addressConfigService;

    /**
     * 查询接单地址配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(AddressConfig addressConfig)
    {
        startPage();
        List<AddressConfig> list = addressConfigService.selectAddressConfigList(addressConfig);
        return getDataTable(list);
    }

    /**
     * 导出接单地址配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:export')")
    @Log(title = "接单地址配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AddressConfig addressConfig) throws IOException {
        List<AddressConfig> list = addressConfigService.selectAddressConfigList(addressConfig);
        ExcelUtil<AddressConfig> util = new ExcelUtil<AddressConfig>(AddressConfig.class);
        util.exportExcel(response, list, "接单地址配置数据");
    }

    /**
     * 获取接单地址配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(addressConfigService.selectAddressConfigById(id));
    }

    /**
     * 新增接单地址配置
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:add')")
    @Log(title = "接单地址配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AddressConfig addressConfig)
    {
        return toAjax(addressConfigService.insertAddressConfig(addressConfig));
    }

    /**
     * 修改接单地址配置
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:edit')")
    @Log(title = "接单地址配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AddressConfig addressConfig)
    {
        return toAjax(addressConfigService.updateAddressConfig(addressConfig));
    }

    /**
     * 删除接单地址配置
     */
    @PreAuthorize("@ss.hasPermi('system:AddressConfig:remove')")
    @Log(title = "接单地址配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(addressConfigService.deleteAddressConfigByIds(ids));
    }
}
