package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ApplyRefundConfig;
import com.ruoyi.system.service.IApplyRefundConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 保证金退还配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/ApplyRefundConfig")
public class ApplyRefundConfigController extends BaseController
{
    @Autowired
    private IApplyRefundConfigService applyRefundConfigService;

    /**
     * 查询保证金退还配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(ApplyRefundConfig applyRefundConfig)
    {
        startPage();
        List<ApplyRefundConfig> list = applyRefundConfigService.selectApplyRefundConfigList(applyRefundConfig);
        return getDataTable(list);
    }

    /**
     * 导出保证金退还配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:export')")
    @Log(title = "保证金退还配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ApplyRefundConfig applyRefundConfig) throws IOException {
        List<ApplyRefundConfig> list = applyRefundConfigService.selectApplyRefundConfigList(applyRefundConfig);
        ExcelUtil<ApplyRefundConfig> util = new ExcelUtil<ApplyRefundConfig>(ApplyRefundConfig.class);
        util.exportExcel(response, list, "保证金退还配置数据");
    }

    /**
     * 获取保证金退还配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(applyRefundConfigService.selectApplyRefundConfigById(id));
    }

    /**
     * 新增保证金退还配置
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:add')")
    @Log(title = "保证金退还配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ApplyRefundConfig applyRefundConfig)
    {
        return toAjax(applyRefundConfigService.insertApplyRefundConfig(applyRefundConfig));
    }

    /**
     * 修改保证金退还配置
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:edit')")
    @Log(title = "保证金退还配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ApplyRefundConfig applyRefundConfig)
    {
        return toAjax(applyRefundConfigService.updateApplyRefundConfig(applyRefundConfig));
    }

    /**
     * 删除保证金退还配置
     */
    @PreAuthorize("@ss.hasPermi('system:ApplyRefundConfig:remove')")
    @Log(title = "保证金退还配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(applyRefundConfigService.deleteApplyRefundConfigByIds(ids));
    }
}
