package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.AppraisalRecords;
import com.ruoyi.system.service.IAppraisalRecordsService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 选择题记录Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/AppraisalRecord")
public class AppraisalRecordsController extends BaseController
{
    @Autowired
    private IAppraisalRecordsService appraisalRecordsService;

    /**
     * 查询选择题记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppraisalRecords appraisalRecords)
    {
        startPage();
        List<AppraisalRecords> list = appraisalRecordsService.selectAppraisalRecordsList(appraisalRecords);
        return getDataTable(list);
    }

    /**
     * 导出选择题记录列表
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:export')")
    @Log(title = "选择题记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppraisalRecords appraisalRecords) throws IOException {
        List<AppraisalRecords> list = appraisalRecordsService.selectAppraisalRecordsList(appraisalRecords);
        ExcelUtil<AppraisalRecords> util = new ExcelUtil<AppraisalRecords>(AppraisalRecords.class);
        util.exportExcel(response, list, "选择题记录数据");
    }

    /**
     * 获取选择题记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:query')")
    @GetMapping(value = "/{appraisalRecordsId}")
    public AjaxResult getInfo(@PathVariable("appraisalRecordsId") Long appraisalRecordsId)
    {
        return success(appraisalRecordsService.selectAppraisalRecordsByAppraisalRecordsId(appraisalRecordsId));
    }

    /**
     * 新增选择题记录
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:add')")
    @Log(title = "选择题记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppraisalRecords appraisalRecords)
    {
        return toAjax(appraisalRecordsService.insertAppraisalRecords(appraisalRecords));
    }

    /**
     * 修改选择题记录
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:edit')")
    @Log(title = "选择题记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppraisalRecords appraisalRecords)
    {
        return toAjax(appraisalRecordsService.updateAppraisalRecords(appraisalRecords));
    }

    /**
     * 删除选择题记录
     */
    @PreAuthorize("@ss.hasPermi('system:AppraisalRecord:remove')")
    @Log(title = "选择题记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{appraisalRecordsIds}")
    public AjaxResult remove(@PathVariable Long[] appraisalRecordsIds)
    {
        return toAjax(appraisalRecordsService.deleteAppraisalRecordsByAppraisalRecordsIds(appraisalRecordsIds));
    }
}
