package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BasicServices;
import com.ruoyi.system.service.IBasicServicesService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 基础服务Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/BasicServices")
public class BasicServicesController extends BaseController
{
    @Autowired
    private IBasicServicesService basicServicesService;

    /**
     * 查询基础服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:list')")
    @GetMapping("/list")
    public TableDataInfo list(BasicServices basicServices)
    {
        startPage();
        List<BasicServices> list = basicServicesService.selectBasicServicesList(basicServices);
        return getDataTable(list);
    }

    /**
     * 导出基础服务列表
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:export')")
    @Log(title = "基础服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BasicServices basicServices) throws IOException {
        List<BasicServices> list = basicServicesService.selectBasicServicesList(basicServices);
        ExcelUtil<BasicServices> util = new ExcelUtil<BasicServices>(BasicServices.class);
        util.exportExcel(response, list, "基础服务数据");
    }

    /**
     * 获取基础服务详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:query')")
    @GetMapping(value = "/{basicServicesId}")
    public AjaxResult getInfo(@PathVariable("basicServicesId") Long basicServicesId)
    {
        return success(basicServicesService.selectBasicServicesByBasicServicesId(basicServicesId));
    }

    /**
     * 新增基础服务
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:add')")
    @Log(title = "基础服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BasicServices basicServices)
    {
        return toAjax(basicServicesService.insertBasicServices(basicServices));
    }

    /**
     * 修改基础服务
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:edit')")
    @Log(title = "基础服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BasicServices basicServices)
    {
        return toAjax(basicServicesService.updateBasicServices(basicServices));
    }

    /**
     * 删除基础服务
     */
    @PreAuthorize("@ss.hasPermi('system:BasicServices:remove')")
    @Log(title = "基础服务", businessType = BusinessType.DELETE)
	@DeleteMapping("/{basicServicesIds}")
    public AjaxResult remove(@PathVariable Long[] basicServicesIds)
    {
        return toAjax(basicServicesService.deleteBasicServicesByBasicServicesIds(basicServicesIds));
    }
}
