package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BondConfig;
import com.ruoyi.system.service.IBondConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 保证金配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/bondconfig")
public class BondConfigController extends BaseController
{
    @Autowired
    private IBondConfigService bondConfigService;

    /**
     * 查询保证金配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(BondConfig bondConfig)
    {
        startPage();
        List<BondConfig> list = bondConfigService.selectBondConfigList(bondConfig);
        return getDataTable(list);
    }

    /**
     * 导出保证金配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:export')")
    @Log(title = "保证金配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BondConfig bondConfig) throws IOException {
        List<BondConfig> list = bondConfigService.selectBondConfigList(bondConfig);
        ExcelUtil<BondConfig> util = new ExcelUtil<BondConfig>(BondConfig.class);
        util.exportExcel(response, list, "保证金配置数据");
    }

    /**
     * 获取保证金配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bondConfigService.selectBondConfigById(id));
    }

    /**
     * 新增保证金配置
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:add')")
    @Log(title = "保证金配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BondConfig bondConfig)
    {
        return toAjax(bondConfigService.insertBondConfig(bondConfig));
    }

    /**
     * 修改保证金配置
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:edit')")
    @Log(title = "保证金配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody BondConfig bondConfig)
    {
        return toAjax(bondConfigService.updateBondConfig(bondConfig));
    }

    /**
     * 删除保证金配置
     */
    @PreAuthorize("@ss.hasPermi('system:bondconfig:remove')")
    @Log(title = "保证金配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bondConfigService.deleteBondConfigByIds(ids));
    }
}
