package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CarouselImage;
import com.ruoyi.system.service.ICarouselImageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮播图Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/CarouselImage")
public class CarouselImageController extends BaseController
{
    @Autowired
    private ICarouselImageService carouselImageService;

    /**
     * 查询轮播图列表
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:list')")
    @GetMapping("/list")
    public TableDataInfo list(CarouselImage carouselImage)
    {
        startPage();
        List<CarouselImage> list = carouselImageService.selectCarouselImageList(carouselImage);
        return getDataTable(list);
    }

    /**
     * 导出轮播图列表
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:export')")
    @Log(title = "轮播图", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CarouselImage carouselImage) throws IOException {
        List<CarouselImage> list = carouselImageService.selectCarouselImageList(carouselImage);
        ExcelUtil<CarouselImage> util = new ExcelUtil<CarouselImage>(CarouselImage.class);
        util.exportExcel(response, list, "轮播图数据");
    }

    /**
     * 获取轮播图详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(carouselImageService.selectCarouselImageById(id));
    }

    /**
     * 新增轮播图
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:add')")
    @Log(title = "轮播图", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CarouselImage carouselImage)
    {
        return toAjax(carouselImageService.insertCarouselImage(carouselImage));
    }

    /**
     * 修改轮播图
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:edit')")
    @Log(title = "轮播图", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CarouselImage carouselImage)
    {
        return toAjax(carouselImageService.updateCarouselImage(carouselImage));
    }

    /**
     * 删除轮播图
     */
    @PreAuthorize("@ss.hasPermi('system:CarouselImage:remove')")
    @Log(title = "轮播图", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(carouselImageService.deleteCarouselImageByIds(ids));
    }
}
