package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CertificationAuditConfig;
import com.ruoyi.system.service.ICertificationAuditConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 认证审核配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/CertificationAuditConfig")
public class CertificationAuditConfigController extends BaseController
{
    @Autowired
    private ICertificationAuditConfigService certificationAuditConfigService;

    /**
     * 查询认证审核配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(CertificationAuditConfig certificationAuditConfig)
    {
        startPage();
        List<CertificationAuditConfig> list = certificationAuditConfigService.selectCertificationAuditConfigList(certificationAuditConfig);
        return getDataTable(list);
    }

    /**
     * 导出认证审核配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:export')")
    @Log(title = "认证审核配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CertificationAuditConfig certificationAuditConfig) throws IOException {
        List<CertificationAuditConfig> list = certificationAuditConfigService.selectCertificationAuditConfigList(certificationAuditConfig);
        ExcelUtil<CertificationAuditConfig> util = new ExcelUtil<CertificationAuditConfig>(CertificationAuditConfig.class);
        util.exportExcel(response, list, "认证审核配置数据");
    }

    /**
     * 获取认证审核配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(certificationAuditConfigService.selectCertificationAuditConfigById(id));
    }

    /**
     * 新增认证审核配置
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:add')")
    @Log(title = "认证审核配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CertificationAuditConfig certificationAuditConfig)
    {
        return toAjax(certificationAuditConfigService.insertCertificationAuditConfig(certificationAuditConfig));
    }

    /**
     * 修改认证审核配置
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:edit')")
    @Log(title = "认证审核配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CertificationAuditConfig certificationAuditConfig)
    {
        return toAjax(certificationAuditConfigService.updateCertificationAuditConfig(certificationAuditConfig));
    }

    /**
     * 删除认证审核配置
     */
    @PreAuthorize("@ss.hasPermi('system:CertificationAuditConfig:remove')")
    @Log(title = "认证审核配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(certificationAuditConfigService.deleteCertificationAuditConfigByIds(ids));
    }
}
