package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Certification;
import com.ruoyi.system.service.ICertificationService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 伴宠师认证Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/certification")
public class CertificationController extends BaseController
{
    @Autowired
    private ICertificationService certificationService;

    /**
     * 查询伴宠师认证列表
     */
    @PreAuthorize("@ss.hasPermi('system:certification:list')")
    @GetMapping("/list")
    public TableDataInfo list(Certification certification)
    {
        startPage();
        List<Certification> list = certificationService.selectCertificationList(certification);
        return getDataTable(list);
    }

    /**
     * 导出伴宠师认证列表
     */
    @PreAuthorize("@ss.hasPermi('system:certification:export')")
    @Log(title = "伴宠师认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Certification certification) throws IOException {
        List<Certification> list = certificationService.selectCertificationList(certification);
        ExcelUtil<Certification> util = new ExcelUtil<Certification>(Certification.class);
        util.exportExcel(response, list, "伴宠师认证数据");
    }

    /**
     * 获取伴宠师认证详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:certification:query')")
    @GetMapping(value = "/{certificationId}")
    public AjaxResult getInfo(@PathVariable("certificationId") Long certificationId)
    {
        return success(certificationService.selectCertificationByCertificationId(certificationId));
    }

    /**
     * 新增伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:certification:add')")
    @Log(title = "伴宠师认证", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Certification certification)
    {
        return toAjax(certificationService.insertCertification(certification));
    }

    /**
     * 修改伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:certification:edit')")
    @Log(title = "伴宠师认证", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Certification certification)
    {
        return toAjax(certificationService.updateCertification(certification));
    }

    /**
     * 删除伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:certification:remove')")
    @Log(title = "伴宠师认证", businessType = BusinessType.DELETE)
	@DeleteMapping("/{certificationIds}")
    public AjaxResult remove(@PathVariable Long[] certificationIds)
    {
        return toAjax(certificationService.deleteCertificationByCertificationIds(certificationIds));
    }
}
