package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CertificationJoinLicense;
import com.ruoyi.system.service.ICertificationJoinLicenseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 执照连接伴宠师认证Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/license")
public class CertificationJoinLicenseController extends BaseController
{
    @Autowired
    private ICertificationJoinLicenseService certificationJoinLicenseService;

    /**
     * 查询执照连接伴宠师认证列表
     */
    @PreAuthorize("@ss.hasPermi('system:license:list')")
    @GetMapping("/list")
    public TableDataInfo list(CertificationJoinLicense certificationJoinLicense)
    {
        startPage();
        List<CertificationJoinLicense> list = certificationJoinLicenseService.selectCertificationJoinLicenseList(certificationJoinLicense);
        return getDataTable(list);
    }

    /**
     * 导出执照连接伴宠师认证列表
     */
    @PreAuthorize("@ss.hasPermi('system:license:export')")
    @Log(title = "执照连接伴宠师认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CertificationJoinLicense certificationJoinLicense) throws IOException {
        List<CertificationJoinLicense> list = certificationJoinLicenseService.selectCertificationJoinLicenseList(certificationJoinLicense);
        ExcelUtil<CertificationJoinLicense> util = new ExcelUtil<CertificationJoinLicense>(CertificationJoinLicense.class);
        util.exportExcel(response, list, "执照连接伴宠师认证数据");
    }

    /**
     * 获取执照连接伴宠师认证详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:license:query')")
    @GetMapping(value = "/{licenseId}")
    public AjaxResult getInfo(@PathVariable("licenseId") Long licenseId)
    {
        return success(certificationJoinLicenseService.selectCertificationJoinLicenseByLicenseId(licenseId));
    }

    /**
     * 新增执照连接伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:license:add')")
    @Log(title = "执照连接伴宠师认证", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CertificationJoinLicense certificationJoinLicense)
    {
        return toAjax(certificationJoinLicenseService.insertCertificationJoinLicense(certificationJoinLicense));
    }

    /**
     * 修改执照连接伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:license:edit')")
    @Log(title = "执照连接伴宠师认证", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CertificationJoinLicense certificationJoinLicense)
    {
        return toAjax(certificationJoinLicenseService.updateCertificationJoinLicense(certificationJoinLicense));
    }

    /**
     * 删除执照连接伴宠师认证
     */
    @PreAuthorize("@ss.hasPermi('system:license:remove')")
    @Log(title = "执照连接伴宠师认证", businessType = BusinessType.DELETE)
	@DeleteMapping("/{licenseIds}")
    public AjaxResult remove(@PathVariable Long[] licenseIds)
    {
        return toAjax(certificationJoinLicenseService.deleteCertificationJoinLicenseByLicenseIds(licenseIds));
    }
}
