package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CheckImage;
import com.ruoyi.system.service.ICheckImageService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 打卡图片Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/CheckImage")
public class CheckImageController extends BaseController
{
    @Autowired
    private ICheckImageService checkImageService;

    /**
     * 查询打卡图片列表
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:list')")
    @GetMapping("/list")
    public TableDataInfo list(CheckImage checkImage)
    {
        startPage();
        List<CheckImage> list = checkImageService.selectCheckImageList(checkImage);
        return getDataTable(list);
    }

    /**
     * 导出打卡图片列表
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:export')")
    @Log(title = "打卡图片", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CheckImage checkImage) throws IOException {
        List<CheckImage> list = checkImageService.selectCheckImageList(checkImage);
        ExcelUtil<CheckImage> util = new ExcelUtil<CheckImage>(CheckImage.class);
        util.exportExcel(response, list, "打卡图片数据");
    }

    /**
     * 获取打卡图片详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:query')")
    @GetMapping(value = "/{checkImageId}")
    public AjaxResult getInfo(@PathVariable("checkImageId") Long checkImageId)
    {
        return success(checkImageService.selectCheckImageByCheckImageId(checkImageId));
    }

    /**
     * 新增打卡图片
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:add')")
    @Log(title = "打卡图片", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CheckImage checkImage)
    {
        return toAjax(checkImageService.insertCheckImage(checkImage));
    }

    /**
     * 修改打卡图片
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:edit')")
    @Log(title = "打卡图片", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CheckImage checkImage)
    {
        return toAjax(checkImageService.updateCheckImage(checkImage));
    }

    /**
     * 删除打卡图片
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImage:remove')")
    @Log(title = "打卡图片", businessType = BusinessType.DELETE)
	@DeleteMapping("/{checkImageIds}")
    public AjaxResult remove(@PathVariable Long[] checkImageIds)
    {
        return toAjax(checkImageService.deleteCheckImageByCheckImageIds(checkImageIds));
    }
}
