package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.CheckImageType;
import com.ruoyi.system.service.ICheckImageTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 打卡图片类型Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/CheckImageType")
public class CheckImageTypeController extends BaseController
{
    @Autowired
    private ICheckImageTypeService checkImageTypeService;

    /**
     * 查询打卡图片类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:list')")
    @GetMapping("/list")
    public TableDataInfo list(CheckImageType checkImageType)
    {
        startPage();
        List<CheckImageType> list = checkImageTypeService.selectCheckImageTypeList(checkImageType);
        return getDataTable(list);
    }

    /**
     * 导出打卡图片类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:export')")
    @Log(title = "打卡图片类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CheckImageType checkImageType) throws IOException {
        List<CheckImageType> list = checkImageTypeService.selectCheckImageTypeList(checkImageType);
        ExcelUtil<CheckImageType> util = new ExcelUtil<CheckImageType>(CheckImageType.class);
        util.exportExcel(response, list, "打卡图片类型数据");
    }

    /**
     * 获取打卡图片类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:query')")
    @GetMapping(value = "/{checkImageTypeId}")
    public AjaxResult getInfo(@PathVariable("checkImageTypeId") Long checkImageTypeId)
    {
        return success(checkImageTypeService.selectCheckImageTypeByCheckImageTypeId(checkImageTypeId));
    }

    /**
     * 新增打卡图片类型
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:add')")
    @Log(title = "打卡图片类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CheckImageType checkImageType)
    {
        return toAjax(checkImageTypeService.insertCheckImageType(checkImageType));
    }

    /**
     * 修改打卡图片类型
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:edit')")
    @Log(title = "打卡图片类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CheckImageType checkImageType)
    {
        return toAjax(checkImageTypeService.updateCheckImageType(checkImageType));
    }

    /**
     * 删除打卡图片类型
     */
    @PreAuthorize("@ss.hasPermi('system:CheckImageType:remove')")
    @Log(title = "打卡图片类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{checkImageTypeIds}")
    public AjaxResult remove(@PathVariable Long[] checkImageTypeIds)
    {
        return toAjax(checkImageTypeService.deleteCheckImageTypeByCheckImageTypeIds(checkImageTypeIds));
    }
}
