package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PetsBread;
import com.ruoyi.system.service.IPetsBreadService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 宠物品种Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/bread")
public class PetsBreadController extends BaseController
{
    @Autowired
    private IPetsBreadService petsBreadService;

    /**
     * 查询宠物品种列表
     */
    @PreAuthorize("@ss.hasPermi('system:bread:list')")
    @GetMapping("/list")
    public TableDataInfo list(PetsBread petsBread)
    {
        startPage();
        List<PetsBread> list = petsBreadService.selectPetsBreadList(petsBread);
        return getDataTable(list);
    }

    /**
     * 导出宠物品种列表
     */
    @PreAuthorize("@ss.hasPermi('system:bread:export')")
    @Log(title = "宠物品种", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PetsBread petsBread) throws IOException {
        List<PetsBread> list = petsBreadService.selectPetsBreadList(petsBread);
        ExcelUtil<PetsBread> util = new ExcelUtil<PetsBread>(PetsBread.class);
        util.exportExcel(response, list, "宠物品种数据");
    }

    /**
     * 获取宠物品种详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:bread:query')")
    @GetMapping(value = "/{petBreadId}")
    public AjaxResult getInfo(@PathVariable("petBreadId") Long petBreadId)
    {
        return success(petsBreadService.selectPetsBreadByPetBreadId(petBreadId));
    }

    /**
     * 新增宠物品种
     */
    @PreAuthorize("@ss.hasPermi('system:bread:add')")
    @Log(title = "宠物品种", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PetsBread petsBread)
    {
        return toAjax(petsBreadService.insertPetsBread(petsBread));
    }

    /**
     * 修改宠物品种
     */
    @PreAuthorize("@ss.hasPermi('system:bread:edit')")
    @Log(title = "宠物品种", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PetsBread petsBread)
    {
        return toAjax(petsBreadService.updatePetsBread(petsBread));
    }

    /**
     * 删除宠物品种
     */
    @PreAuthorize("@ss.hasPermi('system:bread:remove')")
    @Log(title = "宠物品种", businessType = BusinessType.DELETE)
	@DeleteMapping("/{petBreadIds}")
    public AjaxResult remove(@PathVariable Long[] petBreadIds)
    {
        return toAjax(petsBreadService.deletePetsBreadByPetBreadIds(petBreadIds));
    }
}
