package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.PlatformAgreementConfig;
import com.ruoyi.system.service.IPlatformAgreementConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 平台协议配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/PlatformAgreementConfig")
public class PlatformAgreementConfigController extends BaseController
{
    @Autowired
    private IPlatformAgreementConfigService platformAgreementConfigService;

    /**
     * 查询平台协议配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(PlatformAgreementConfig platformAgreementConfig)
    {
        startPage();
        List<PlatformAgreementConfig> list = platformAgreementConfigService.selectPlatformAgreementConfigList(platformAgreementConfig);
        return getDataTable(list);
    }

    /**
     * 导出平台协议配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:export')")
    @Log(title = "平台协议配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PlatformAgreementConfig platformAgreementConfig) throws IOException {
        List<PlatformAgreementConfig> list = platformAgreementConfigService.selectPlatformAgreementConfigList(platformAgreementConfig);
        ExcelUtil<PlatformAgreementConfig> util = new ExcelUtil<PlatformAgreementConfig>(PlatformAgreementConfig.class);
        util.exportExcel(response, list, "平台协议配置数据");
    }

    /**
     * 获取平台协议配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(platformAgreementConfigService.selectPlatformAgreementConfigById(id));
    }

    /**
     * 新增平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:add')")
    @Log(title = "平台协议配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody PlatformAgreementConfig platformAgreementConfig)
    {
        return toAjax(platformAgreementConfigService.insertPlatformAgreementConfig(platformAgreementConfig));
    }

    /**
     * 修改平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:edit')")
    @Log(title = "平台协议配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody PlatformAgreementConfig platformAgreementConfig)
    {
        return toAjax(platformAgreementConfigService.updatePlatformAgreementConfig(platformAgreementConfig));
    }

    /**
     * 删除平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('system:PlatformAgreementConfig:remove')")
    @Log(title = "平台协议配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(platformAgreementConfigService.deletePlatformAgreementConfigByIds(ids));
    }
}
