package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ServiceFile;
import com.ruoyi.system.service.IServiceFileService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务档案Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/file")
public class ServiceFileController extends BaseController
{
    @Autowired
    private IServiceFileService serviceFileService;

    /**
     * 查询服务档案列表
     */
    @PreAuthorize("@ss.hasPermi('system:file:list')")
    @GetMapping("/list")
    public TableDataInfo list(ServiceFile serviceFile)
    {
        startPage();
        List<ServiceFile> list = serviceFileService.selectServiceFileList(serviceFile);
        return getDataTable(list);
    }

    /**
     * 导出服务档案列表
     */
    @PreAuthorize("@ss.hasPermi('system:file:export')")
    @Log(title = "服务档案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ServiceFile serviceFile) throws IOException {
        List<ServiceFile> list = serviceFileService.selectServiceFileList(serviceFile);
        ExcelUtil<ServiceFile> util = new ExcelUtil<ServiceFile>(ServiceFile.class);
        util.exportExcel(response, list, "服务档案数据");
    }

    /**
     * 获取服务档案详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:file:query')")
    @GetMapping(value = "/{serviceFileId}")
    public AjaxResult getInfo(@PathVariable("serviceFileId") Long serviceFileId)
    {
        return success(serviceFileService.selectServiceFileByServiceFileId(serviceFileId));
    }

    /**
     * 新增服务档案
     */
    @PreAuthorize("@ss.hasPermi('system:file:add')")
    @Log(title = "服务档案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ServiceFile serviceFile)
    {
        return toAjax(serviceFileService.insertServiceFile(serviceFile));
    }

    /**
     * 修改服务档案
     */
    @PreAuthorize("@ss.hasPermi('system:file:edit')")
    @Log(title = "服务档案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ServiceFile serviceFile)
    {
        return toAjax(serviceFileService.updateServiceFile(serviceFile));
    }

    /**
     * 删除服务档案
     */
    @PreAuthorize("@ss.hasPermi('system:file:remove')")
    @Log(title = "服务档案", businessType = BusinessType.DELETE)
	@DeleteMapping("/{serviceFileIds}")
    public AjaxResult remove(@PathVariable Long[] serviceFileIds)
    {
        return toAjax(serviceFileService.deleteServiceFileByServiceFileIds(serviceFileIds));
    }
}
