package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ServiceRecordConfig;
import com.ruoyi.system.service.IServiceRecordConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务记录配置（不存在服务记录时出现）Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/ServiceRecordConfig")
public class ServiceRecordConfigController extends BaseController
{
    @Autowired
    private IServiceRecordConfigService serviceRecordConfigService;

    /**
     * 查询服务记录配置（不存在服务记录时出现）列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(ServiceRecordConfig serviceRecordConfig)
    {
        startPage();
        List<ServiceRecordConfig> list = serviceRecordConfigService.selectServiceRecordConfigList(serviceRecordConfig);
        return getDataTable(list);
    }

    /**
     * 导出服务记录配置（不存在服务记录时出现）列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:export')")
    @Log(title = "服务记录配置（不存在服务记录时出现）", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ServiceRecordConfig serviceRecordConfig) throws IOException {
        List<ServiceRecordConfig> list = serviceRecordConfigService.selectServiceRecordConfigList(serviceRecordConfig);
        ExcelUtil<ServiceRecordConfig> util = new ExcelUtil<ServiceRecordConfig>(ServiceRecordConfig.class);
        util.exportExcel(response, list, "服务记录配置（不存在服务记录时出现）数据");
    }

    /**
     * 获取服务记录配置（不存在服务记录时出现）详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(serviceRecordConfigService.selectServiceRecordConfigById(id));
    }

    /**
     * 新增服务记录配置（不存在服务记录时出现）
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:add')")
    @Log(title = "服务记录配置（不存在服务记录时出现）", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ServiceRecordConfig serviceRecordConfig)
    {
        return toAjax(serviceRecordConfigService.insertServiceRecordConfig(serviceRecordConfig));
    }

    /**
     * 修改服务记录配置（不存在服务记录时出现）
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:edit')")
    @Log(title = "服务记录配置（不存在服务记录时出现）", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ServiceRecordConfig serviceRecordConfig)
    {
        return toAjax(serviceRecordConfigService.updateServiceRecordConfig(serviceRecordConfig));
    }

    /**
     * 删除服务记录配置（不存在服务记录时出现）
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceRecordConfig:remove')")
    @Log(title = "服务记录配置（不存在服务记录时出现）", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(serviceRecordConfigService.deleteServiceRecordConfigByIds(ids));
    }
}
