package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ServiceType;
import com.ruoyi.system.service.IServiceTypeService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务类型Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/ServiceType")
public class ServiceTypeController extends BaseController
{
    @Autowired
    private IServiceTypeService serviceTypeService;

    /**
     * 查询服务类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:list')")
    @GetMapping("/list")
    public TableDataInfo list(ServiceType serviceType)
    {
        startPage();
        List<ServiceType> list = serviceTypeService.selectServiceTypeList(serviceType);
        return getDataTable(list);
    }

    /**
     * 导出服务类型列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:export')")
    @Log(title = "服务类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ServiceType serviceType) throws IOException {
        List<ServiceType> list = serviceTypeService.selectServiceTypeList(serviceType);
        ExcelUtil<ServiceType> util = new ExcelUtil<ServiceType>(ServiceType.class);
        util.exportExcel(response, list, "服务类型数据");
    }

    /**
     * 获取服务类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(serviceTypeService.selectServiceTypeById(id));
    }

    /**
     * 新增服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:add')")
    @Log(title = "服务类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ServiceType serviceType)
    {
        return toAjax(serviceTypeService.insertServiceType(serviceType));
    }

    /**
     * 修改服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:edit')")
    @Log(title = "服务类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ServiceType serviceType)
    {
        return toAjax(serviceTypeService.updateServiceType(serviceType));
    }

    /**
     * 删除服务类型
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceType:remove')")
    @Log(title = "服务类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(serviceTypeService.deleteServiceTypeByIds(ids));
    }
}
