package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.ServiceUploadConfig;
import com.ruoyi.system.service.IServiceUploadConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 服务上传配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/ServiceUploadConfig")
public class ServiceUploadConfigController extends BaseController
{
    @Autowired
    private IServiceUploadConfigService serviceUploadConfigService;

    /**
     * 查询服务上传配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(ServiceUploadConfig serviceUploadConfig)
    {
        startPage();
        List<ServiceUploadConfig> list = serviceUploadConfigService.selectServiceUploadConfigList(serviceUploadConfig);
        return getDataTable(list);
    }

    /**
     * 导出服务上传配置列表
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:export')")
    @Log(title = "服务上传配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, ServiceUploadConfig serviceUploadConfig) throws IOException {
        List<ServiceUploadConfig> list = serviceUploadConfigService.selectServiceUploadConfigList(serviceUploadConfig);
        ExcelUtil<ServiceUploadConfig> util = new ExcelUtil<ServiceUploadConfig>(ServiceUploadConfig.class);
        util.exportExcel(response, list, "服务上传配置数据");
    }

    /**
     * 获取服务上传配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(serviceUploadConfigService.selectServiceUploadConfigById(id));
    }

    /**
     * 新增服务上传配置
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:add')")
    @Log(title = "服务上传配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody ServiceUploadConfig serviceUploadConfig)
    {
        return toAjax(serviceUploadConfigService.insertServiceUploadConfig(serviceUploadConfig));
    }

    /**
     * 修改服务上传配置
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:edit')")
    @Log(title = "服务上传配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody ServiceUploadConfig serviceUploadConfig)
    {
        return toAjax(serviceUploadConfigService.updateServiceUploadConfig(serviceUploadConfig));
    }

    /**
     * 删除服务上传配置
     */
    @PreAuthorize("@ss.hasPermi('system:ServiceUploadConfig:remove')")
    @Log(title = "服务上传配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(serviceUploadConfigService.deleteServiceUploadConfigByIds(ids));
    }
}
