package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.Tool;
import com.ruoyi.system.service.IToolService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工具Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/tool")
public class ToolController extends BaseController
{
    @Autowired
    private IToolService toolService;

    /**
     * 查询工具列表
     */
    @PreAuthorize("@ss.hasPermi('system:tool:list')")
    @GetMapping("/list")
    public TableDataInfo list(Tool tool)
    {
        startPage();
        List<Tool> list = toolService.selectToolList(tool);
        return getDataTable(list);
    }

    /**
     * 导出工具列表
     */
    @PreAuthorize("@ss.hasPermi('system:tool:export')")
    @Log(title = "工具", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Tool tool) throws IOException {
        List<Tool> list = toolService.selectToolList(tool);
        ExcelUtil<Tool> util = new ExcelUtil<Tool>(Tool.class);
        util.exportExcel(response, list, "工具数据");
    }

    /**
     * 获取工具详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:tool:query')")
    @GetMapping(value = "/{toolId}")
    public AjaxResult getInfo(@PathVariable("toolId") Long toolId)
    {
        return success(toolService.selectToolByToolId(toolId));
    }

    /**
     * 新增工具
     */
    @PreAuthorize("@ss.hasPermi('system:tool:add')")
    @Log(title = "工具", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Tool tool)
    {
        return toAjax(toolService.insertTool(tool));
    }

    /**
     * 修改工具
     */
    @PreAuthorize("@ss.hasPermi('system:tool:edit')")
    @Log(title = "工具", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Tool tool)
    {
        return toAjax(toolService.updateTool(tool));
    }

    /**
     * 删除工具
     */
    @PreAuthorize("@ss.hasPermi('system:tool:remove')")
    @Log(title = "工具", businessType = BusinessType.DELETE)
	@DeleteMapping("/{toolIds}")
    public AjaxResult remove(@PathVariable Long[] toolIds)
    {
        return toAjax(toolService.deleteToolByToolIds(toolIds));
    }
}
