package com.ruoyi.system.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.WalkDog;
import com.ruoyi.system.service.IWalkDogService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 遛狗要求Controller
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@RestController
@RequestMapping("/system/dog")
public class WalkDogController extends BaseController
{
    @Autowired
    private IWalkDogService walkDogService;

    /**
     * 查询遛狗要求列表
     */
    @PreAuthorize("@ss.hasPermi('system:dog:list')")
    @GetMapping("/list")
    public TableDataInfo list(WalkDog walkDog)
    {
        startPage();
        List<WalkDog> list = walkDogService.selectWalkDogList(walkDog);
        return getDataTable(list);
    }

    /**
     * 导出遛狗要求列表
     */
    @PreAuthorize("@ss.hasPermi('system:dog:export')")
    @Log(title = "遛狗要求", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, WalkDog walkDog) throws IOException {
        List<WalkDog> list = walkDogService.selectWalkDogList(walkDog);
        ExcelUtil<WalkDog> util = new ExcelUtil<WalkDog>(WalkDog.class);
        util.exportExcel(response, list, "遛狗要求数据");
    }

    /**
     * 获取遛狗要求详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:dog:query')")
    @GetMapping(value = "/{walkDogId}")
    public AjaxResult getInfo(@PathVariable("walkDogId") Long walkDogId)
    {
        return success(walkDogService.selectWalkDogByWalkDogId(walkDogId));
    }

    /**
     * 新增遛狗要求
     */
    @PreAuthorize("@ss.hasPermi('system:dog:add')")
    @Log(title = "遛狗要求", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody WalkDog walkDog)
    {
        return toAjax(walkDogService.insertWalkDog(walkDog));
    }

    /**
     * 修改遛狗要求
     */
    @PreAuthorize("@ss.hasPermi('system:dog:edit')")
    @Log(title = "遛狗要求", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody WalkDog walkDog)
    {
        return toAjax(walkDogService.updateWalkDog(walkDog));
    }

    /**
     * 删除遛狗要求
     */
    @PreAuthorize("@ss.hasPermi('system:dog:remove')")
    @Log(title = "遛狗要求", businessType = BusinessType.DELETE)
	@DeleteMapping("/{walkDogIds}")
    public AjaxResult remove(@PathVariable Long[] walkDogIds)
    {
        return toAjax(walkDogService.deleteWalkDogByWalkDogIds(walkDogIds));
    }
}
