package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.AdditionalServicesTypeMapper;
import com.ruoyi.system.domain.AdditionalServicesType;
import com.ruoyi.system.service.IAdditionalServicesTypeService;

/**
 * 附加服务类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class AdditionalServicesTypeServiceImpl implements IAdditionalServicesTypeService 
{
    @Autowired
    private AdditionalServicesTypeMapper additionalServicesTypeMapper;

    /**
     * 查询附加服务类型
     * 
     * @param additionalServicesTypeId 附加服务类型主键
     * @return 附加服务类型
     */
    @Override
    public AdditionalServicesType selectAdditionalServicesTypeByAdditionalServicesTypeId(Long additionalServicesTypeId)
    {
        return additionalServicesTypeMapper.selectAdditionalServicesTypeByAdditionalServicesTypeId(additionalServicesTypeId);
    }

    /**
     * 查询附加服务类型列表
     * 
     * @param additionalServicesType 附加服务类型
     * @return 附加服务类型
     */
    @Override
    public List<AdditionalServicesType> selectAdditionalServicesTypeList(AdditionalServicesType additionalServicesType)
    {
        return additionalServicesTypeMapper.selectAdditionalServicesTypeList(additionalServicesType);
    }

    /**
     * 新增附加服务类型
     * 
     * @param additionalServicesType 附加服务类型
     * @return 结果
     */
    @Override
    public int insertAdditionalServicesType(AdditionalServicesType additionalServicesType)
    {
        additionalServicesType.setCreateTime(DateUtils.getNowDate());
        return additionalServicesTypeMapper.insertAdditionalServicesType(additionalServicesType);
    }

    /**
     * 修改附加服务类型
     * 
     * @param additionalServicesType 附加服务类型
     * @return 结果
     */
    @Override
    public int updateAdditionalServicesType(AdditionalServicesType additionalServicesType)
    {
        additionalServicesType.setUpdateTime(DateUtils.getNowDate());
        return additionalServicesTypeMapper.updateAdditionalServicesType(additionalServicesType);
    }

    /**
     * 批量删除附加服务类型
     * 
     * @param additionalServicesTypeIds 需要删除的附加服务类型主键
     * @return 结果
     */
    @Override
    public int deleteAdditionalServicesTypeByAdditionalServicesTypeIds(Long[] additionalServicesTypeIds)
    {
        return additionalServicesTypeMapper.deleteAdditionalServicesTypeByAdditionalServicesTypeIds(additionalServicesTypeIds);
    }

    /**
     * 删除附加服务类型信息
     * 
     * @param additionalServicesTypeId 附加服务类型主键
     * @return 结果
     */
    @Override
    public int deleteAdditionalServicesTypeByAdditionalServicesTypeId(Long additionalServicesTypeId)
    {
        return additionalServicesTypeMapper.deleteAdditionalServicesTypeByAdditionalServicesTypeId(additionalServicesTypeId);
    }
}
