package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.CertificationMapper;
import com.ruoyi.system.domain.Certification;
import com.ruoyi.system.service.ICertificationService;

/**
 * 伴宠师认证Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class CertificationServiceImpl implements ICertificationService 
{
    @Autowired
    private CertificationMapper certificationMapper;

    /**
     * 查询伴宠师认证
     * 
     * @param certificationId 伴宠师认证主键
     * @return 伴宠师认证
     */
    @Override
    public Certification selectCertificationByCertificationId(Long certificationId)
    {
        return certificationMapper.selectCertificationByCertificationId(certificationId);
    }

    /**
     * 查询伴宠师认证列表
     * 
     * @param certification 伴宠师认证
     * @return 伴宠师认证
     */
    @Override
    public List<Certification> selectCertificationList(Certification certification)
    {
        return certificationMapper.selectCertificationList(certification);
    }

    /**
     * 新增伴宠师认证
     * 
     * @param certification 伴宠师认证
     * @return 结果
     */
    @Override
    public int insertCertification(Certification certification)
    {
        certification.setCreateTime(DateUtils.getNowDate());
        return certificationMapper.insertCertification(certification);
    }

    /**
     * 修改伴宠师认证
     * 
     * @param certification 伴宠师认证
     * @return 结果
     */
    @Override
    public int updateCertification(Certification certification)
    {
        certification.setUpdateTime(DateUtils.getNowDate());
        return certificationMapper.updateCertification(certification);
    }

    /**
     * 批量删除伴宠师认证
     * 
     * @param certificationIds 需要删除的伴宠师认证主键
     * @return 结果
     */
    @Override
    public int deleteCertificationByCertificationIds(Long[] certificationIds)
    {
        return certificationMapper.deleteCertificationByCertificationIds(certificationIds);
    }

    /**
     * 删除伴宠师认证信息
     * 
     * @param certificationId 伴宠师认证主键
     * @return 结果
     */
    @Override
    public int deleteCertificationByCertificationId(Long certificationId)
    {
        return certificationMapper.deleteCertificationByCertificationId(certificationId);
    }
}
