package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ServiceTypeMapper;
import com.ruoyi.system.domain.ServiceType;
import com.ruoyi.system.service.IServiceTypeService;

/**
 * 服务类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class ServiceTypeServiceImpl implements IServiceTypeService 
{
    @Autowired
    private ServiceTypeMapper serviceTypeMapper;

    /**
     * 查询服务类型
     * 
     * @param id 服务类型主键
     * @return 服务类型
     */
    @Override
    public ServiceType selectServiceTypeById(Long id)
    {
        return serviceTypeMapper.selectServiceTypeById(id);
    }

    /**
     * 查询服务类型列表
     * 
     * @param serviceType 服务类型
     * @return 服务类型
     */
    @Override
    public List<ServiceType> selectServiceTypeList(ServiceType serviceType)
    {
        return serviceTypeMapper.selectServiceTypeList(serviceType);
    }

    /**
     * 新增服务类型
     * 
     * @param serviceType 服务类型
     * @return 结果
     */
    @Override
    public int insertServiceType(ServiceType serviceType)
    {
        serviceType.setCreateTime(DateUtils.getNowDate());
        return serviceTypeMapper.insertServiceType(serviceType);
    }

    /**
     * 修改服务类型
     * 
     * @param serviceType 服务类型
     * @return 结果
     */
    @Override
    public int updateServiceType(ServiceType serviceType)
    {
        serviceType.setUpdateTime(DateUtils.getNowDate());
        return serviceTypeMapper.updateServiceType(serviceType);
    }

    /**
     * 批量删除服务类型
     * 
     * @param ids 需要删除的服务类型主键
     * @return 结果
     */
    @Override
    public int deleteServiceTypeByIds(Long[] ids)
    {
        return serviceTypeMapper.deleteServiceTypeByIds(ids);
    }

    /**
     * 删除服务类型信息
     * 
     * @param id 服务类型主键
     * @return 结果
     */
    @Override
    public int deleteServiceTypeById(Long id)
    {
        return serviceTypeMapper.deleteServiceTypeById(id);
    }
}
