package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.ToolMapper;
import com.ruoyi.system.domain.Tool;
import com.ruoyi.system.service.IToolService;

/**
 * 工具Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-02
 */
@Service
public class ToolServiceImpl implements IToolService 
{
    @Autowired
    private ToolMapper toolMapper;

    /**
     * 查询工具
     * 
     * @param toolId 工具主键
     * @return 工具
     */
    @Override
    public Tool selectToolByToolId(Long toolId)
    {
        return toolMapper.selectToolByToolId(toolId);
    }

    /**
     * 查询工具列表
     * 
     * @param tool 工具
     * @return 工具
     */
    @Override
    public List<Tool> selectToolList(Tool tool)
    {
        return toolMapper.selectToolList(tool);
    }

    /**
     * 新增工具
     * 
     * @param tool 工具
     * @return 结果
     */
    @Override
    public int insertTool(Tool tool)
    {
        tool.setCreateTime(DateUtils.getNowDate());
        return toolMapper.insertTool(tool);
    }

    /**
     * 修改工具
     * 
     * @param tool 工具
     * @return 结果
     */
    @Override
    public int updateTool(Tool tool)
    {
        tool.setUpdateTime(DateUtils.getNowDate());
        return toolMapper.updateTool(tool);
    }

    /**
     * 批量删除工具
     * 
     * @param toolIds 需要删除的工具主键
     * @return 结果
     */
    @Override
    public int deleteToolByToolIds(Long[] toolIds)
    {
        return toolMapper.deleteToolByToolIds(toolIds);
    }

    /**
     * 删除工具信息
     * 
     * @param toolId 工具主键
     * @return 结果
     */
    @Override
    public int deleteToolByToolId(Long toolId)
    {
        return toolMapper.deleteToolByToolId(toolId);
    }
}
